@@ -285,7 +285,10 @@ class Character:
         :return: A 2-tuple containing the target chair and the direction it
                  faces.
         """
-        return self.room.get_next_chair(self, move_along and self.changes_seats, go_to_back)
+        if self.room:
+            return self.room.get_next_chair(self, move_along and self.changes_seats, go_to_back)
+        debug.error("Character %s (%s) at (%s,%s) cannot find a chair because self.room == None" % (self.character_id, self.name, self.x, self.y))
+        return None, 1
 
     def say(self, words, shift):
         """Make the character start or continue saying something.
@@ -594,7 +597,7 @@ class Character:
         will be true if the character:
 
         * can smell stinkbombs generally, and
-        * is standing up. and
+        * is standing up, and
         * is on the same floor as and within smelling range of the stinkbomb
 
         :param stinkbomb: The stinkbomb to check.
