@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2008, 2010 Richard Dymond (rjdymond@gmail.com)
+# Copyright 2008-2011 Richard Dymond (rjdymond@gmail.com)
 #
 # This file is part of Pyskool.
 #
@@ -473,6 +473,7 @@ class Eric(character.Character):
         action is taken. Eric will descend to the floor unless the jump placed
         him on a knocked out kid or a plant pot.
         """
+        self.play_sound(sound.JUMP)
         x, y = self.get_location_above_hand()
         self.skool.check_safe(x, y, items.SAFE_KEY in self.inventory)
         self.check_shields_at(x, y)
@@ -665,6 +666,7 @@ class Eric(character.Character):
         :param command_list_id: The ID of the command list Mr Wacker should
                                 switch to.
         """
+        self.expelled = True
         self.skool.expel_eric(command_list_id)
 
     def take_safe_key(self):
@@ -786,7 +788,7 @@ class Eric(character.Character):
         """
         self.bike_key = None
         for key in keys.LEFT + keys.RIGHT + keys.UP + keys.DOWN + keys.JUMP:
-            if self.keyboard.was_pressed(key):
+            if self.keyboard.was_pressed([key]):
                 self.bike_key = key
                 break
 
