@@ -622,6 +622,7 @@ class Screen(object):
 class Gallery:
     """A container for all the images used in a game.
 
+    :param images_dir: The path to the `images` directory.
     :type config: dict
     :param config: Configuration parameters from the ini file.
     :param scale: The desired scale of the images; if `None`, the `Scale`
@@ -629,17 +630,25 @@ class Gallery:
     :type images: dict
     :param images: Key-value pairs (image ID, path) from the `Images` section.
     """
-    def __init__(self, config, scale, images):
-        self.images_dir = config.get('ImagesDir', 'images')
+    def __init__(self, images_dir, config, scale, images):
+        self.images_dir = images_dir
         self.image_set = config.get('ImageSet', 'original')
         self.images = images
         self.reset(scale or config.get('Scale', 2))
 
     def __getstate__(self):
         d = self.__dict__.copy()
+        d['images_dir'] = None
         d['surfaces'] = {}
         return d
 
+    def restore(self, images_dir):
+        """Perform tasks required immediately after loading a saved game.
+
+        :param images_dir: The path to the `images` directory.
+        """
+        self.images_dir = images_dir
+
     def reset(self, scale):
         """Set the scale and clear the image cache.
 
@@ -695,12 +704,11 @@ class Gallery:
         if image_id not in self.images:
             return None
         scale_up = True
-        images_dir = os.path.join(*self.images_dir.split('/'))
-        image_set_dir = os.path.join(images_dir, '%sx%i' % (self.image_set, self.scale))
+        image_set_dir = os.path.join(self.images_dir, '%sx%i' % (self.image_set, self.scale))
         if os.path.isdir(image_set_dir):
             scale_up = False
         else:
-            image_set_dir = os.path.join(images_dir, '%sx1' % self.image_set)
+            image_set_dir = os.path.join(self.images_dir, '%sx1' % self.image_set)
         fname = os.path.join(*self.images[image_id].split('/'))
         image_file = os.path.join(image_set_dir, fname)
         if not os.path.isfile(image_file):
@@ -726,19 +734,18 @@ class Image:
     :param top_left: The coordinates of the top-left corner of this image
                      inside the parent image.
     :param flipped: If `True`, the image will be flipped before use.
+    :param colorkey: The colour key.
     """
-    def __init__(self, gallery, image_id, surface, top_left=None, size=None, flipped=False):
+    def __init__(self, gallery, image_id, surface, top_left=None, size=None, flipped=False, colorkey=None):
         self.gallery = gallery
         self.image_id = image_id
         self.surface = surface
         self.top_left = top_left
         self.flipped = flipped
         self.size = size
-        self.colorkey = None
-        if self.surface:
-            self.colorkey = surface.get_colorkey()
-            if self.flipped:
-                self._flip_surface()
+        self.colorkey = colorkey
+        if self.surface and flipped:
+            self._flip_surface()
 
     def __getstate__(self):
         d = self.__dict__.copy()
@@ -780,11 +787,11 @@ class Image:
         :param size: The size of the subsurface.
         """
         surface = self.surface.subsurface(self._scale_coords(coords), self._scale_coords(size))
-        return Image(self.gallery, self.image_id, surface, coords, size, self.flipped)
+        return Image(self.gallery, self.image_id, surface, coords, size, self.flipped, self.colorkey)
 
     def copy(self):
         """Return a copy of the image."""
-        return Image(self.gallery, self.image_id, self.surface.copy(), self.top_left, self.size, self.flipped)
+        return Image(self.gallery, self.image_id, self.surface.copy(), self.top_left, self.size, self.flipped, self.colorkey)
 
     def get_width(self):
         """Return the width of the image."""
@@ -812,7 +819,7 @@ class Image:
 
     def flip(self):
         """Return a flipped copy of the image."""
-        return Image(self.gallery, self.image_id, self.surface, self.top_left, self.size, True)
+        return Image(self.gallery, self.image_id, self.surface, self.top_left, self.size, True, self.colorkey)
 
     def blit(self, *args):
         """Blit a `pygame.Surface` onto this image.
