@@ -17,8 +17,8 @@
 
 """
 IDs of the items that can be displayed in Eric's inventory. The image
-specifications for each item are defined in the `Inventory` section of the ini
-file.
+specifications for each item are defined in the :ref:`inventory` section of the
+ini file.
 """
 
 #: Captured frog.
