@@ -137,7 +137,12 @@ class SkoolMemory:
         return self.get_box_graphic(self.logo_address)
 
     def get_score_box_udgs(self):
-        return self.get_box_graphic(self.score_box_address)
+        udg = Udg(self.snapshot[self.score_box_address], [0] * 8)
+        return [[udg] * 8] * 3
+
+    def get_lesson_box_udgs(self):
+        udg = Udg(self.lesson_box_attr, [0] * 8)
+        return [[udg] * 8] * 3
 
     def _get_box_udg(self, address, row, col, attr=None):
         if attr is None:
@@ -185,6 +190,7 @@ class SDMemory(SkoolMemory):
         SkoolMemory.__init__(self, snafile, custom)
         self.font_address = 55552
         self.logo_address = 61184
+        self.lesson_box_attr = 5
         self.score_box_address = 60928
 
     def get_skool_udg(self, y, x):
@@ -217,6 +223,18 @@ class SDMemory(SkoolMemory):
         udgs[1].append(_BLANK_UDG)
         return udgs
 
+    def fix_bubble(self, pixels):
+        """Add transparency to the speech bubble."""
+        for y, x in (
+            (0,  0), (0,  1), (0, 62), (0, 63),
+            (1,  0), (1, 63),
+            (4, 64), (4, 71),
+            (5, 64), (5, 71),
+            (6, 64), (6, 65), (6, 71),
+            (7, 64), (7, 65), (7, 66), (7, 70), (7, 71)
+        ):
+            pixels[y][x] = 16
+
     def get_mutable_udgs(self):
         udgs = []
         for x, y in ((6, 2), (8, 2), (47, 2), (50, 2), (78, 2), (45, 8), (50, 8), (65, 14), (67, 14)):
@@ -261,6 +279,69 @@ class SDMemory(SkoolMemory):
         self.snapshot[50827] = 123 # Main kids' shoes (facing right)
         self.snapshot[50814] = 222 # Little kids' shoes (facing left)
         self.snapshot[50942] = 123 # Little kids' shoes (facing right)
+        self.snapshot[47627] = 231 # Big kids' hands (facing left)
+        self.snapshot[47755] = 231 # Big kids' hands (facing right)
+        self.snapshot[47742] = 247 # Little kids' hands (facing left)
+        self.snapshot[47870] = 239 # Little kids' hands (facing right)
+        self.snapshot[52599] = 30  # Mr Creak's hand (1) (facing left)
+        self.snapshot[52855] = 222 # Mr Creak's hand (2) (facing left)
+        self.snapshot[52727] = 120 # Mr Creak's hand (1) (facing right)
+        self.snapshot[52983] = 123 # Mr Creak's hand (2) (facing right)
+
+        # MR ROCKITT's lab coat (arm up, facing left)
+        self.snapshot[51996] = 232
+        self.snapshot[52252] = 232
+        self.snapshot[53020] = 36
+        self.snapshot[53276] = 164
+        self.snapshot[53532] = 44
+        self.snapshot[53788] = 172
+        self.snapshot[54044] = 46
+        self.snapshot[54300] = 174
+        self.snapshot[54556] = 54
+        self.snapshot[54812] = 182
+        self.snapshot[55068] = 53
+        self.snapshot[55324] = 181
+
+        # MR ROCKITT's lab coat (arm up, facing right)
+        self.snapshot[52124] = 23
+        self.snapshot[52380] = 23
+        self.snapshot[53148] = 36
+        self.snapshot[53404] = 37
+        self.snapshot[53660] = 52
+        self.snapshot[53916] = 53
+        self.snapshot[54172] = 116
+        self.snapshot[54428] = 117
+        self.snapshot[54684] = 108
+        self.snapshot[54940] = 109
+        self.snapshot[55196] = 172
+        self.snapshot[55452] = 173
+
+    def fix_sprites(self, pixels):
+        """Apply fixes to graphic glitches that cannot be fixed by adjusting
+        tiles (because the tiles are used in multiple places, and the fix
+        applies to a subset of those places).
+        """
+        for y, x in (
+            # Eric's face
+            ( 10,   7), ( 10,  55), ( 10, 103), ( 10, 127), ( 10, 199), ( 10, 247), ( 10, 271), ( 10, 295),
+            ( 11,   7), ( 11,  55), ( 11, 103), ( 11, 127), ( 11, 199), ( 11, 247), ( 11, 271), ( 11, 295),
+            ( 12,   7), ( 12,  55), ( 12, 103), ( 12, 127), ( 12, 199), ( 12, 247), ( 12, 271), ( 12, 295),
+            ( 13,   7), ( 13,  55), ( 13, 103), ( 13, 127), ( 13, 199), ( 13, 247),             ( 13, 295),
+            ( 14,   7), ( 14,  55), ( 14, 103), ( 14, 127), ( 14, 199), ( 14, 247),
+
+            # BOY WANDER's face
+            (105,   7), (105,  55), (105, 103), (105, 127), (105, 199), (105, 295),
+            (107,   7), (107,  55), (107, 103), (107, 127), (107, 199), (107, 295),
+            (108,   7), (108,  55), (108, 103), (108, 127), (108, 199), (108, 295),
+            (109,   7), (109,  55), (109, 103), (109, 127), (109, 199), (109, 295),
+            (110,   7), (110,  55), (110, 103), (110, 127), (110, 199),
+
+            # ANGELFACE's head
+            ( 73,   7), ( 73,  55), ( 73, 103), ( 73, 127), ( 73, 247), ( 73, 271), ( 73, 295),
+
+            (191,  55) # MR WACKER's foot
+        ):
+            pixels[y][x] = 16
 
     def get_play_area_udgs(self):
         return self.get_skool_udgs(0, 0, 96, 21)
@@ -293,11 +374,28 @@ class SDMemory(SkoolMemory):
             for j, p in enumerate(p_row):
                 logo_udgs[0][j + 5].data[i + 1] = int(p, 2)
 
+    def get_message_box_udgs(self):
+        udgs = self.get_box_graphic(60160)
+
+        # Set the attributes
+        for row in udgs:
+            for udg in row:
+                udg.attr = 23
+
+        # Remove the '0 lines' graphic
+        blank = [0] * 4
+        for x in (3, 4, 5, 6):
+            udgs[0][x].data[4:] = blank
+            udgs[1][x].data[:4] = blank
+
+        return udgs
+
 class BTSMemory(SkoolMemory):
     def __init__(self, snafile, custom):
         SkoolMemory.__init__(self, snafile, custom)
         self.font_address = 55040
         self.logo_address = 59176
+        self.lesson_box_attr = 87
         self.score_box_address = 58920
 
     def get_skool_udg(self, y, x):
@@ -356,6 +454,20 @@ class BTSMemory(SkoolMemory):
         udgs[1].append(_BLANK_UDG)
         return udgs
 
+    def fix_bubble(self, pixels):
+        """Add transparency to the speech bubble."""
+        for y, x in (
+            ( 0,  0), ( 0, 63),
+            ( 2, 64),
+            ( 3, 64), ( 3, 71),
+            ( 4, 64), ( 4, 71),
+            ( 5, 64), ( 5, 65), (5, 71),
+            ( 6, 64), ( 6, 65), (6, 71),
+            ( 7, 64), ( 7, 65), (7, 66), (7, 70), (7, 71),
+            (15,  0), (15, 63)
+        ):
+            pixels[y][x] = 16
+
     def _alter_skool_udgs(self, address):
         coords = []
         while True:
@@ -566,6 +678,62 @@ class BTSMemory(SkoolMemory):
         self.snapshot[54487] = 250 # MR WITHIT's and ALBERT's shoes (4)
         self.snapshot[51417] = 235 # MR WITHIT's and MISS TAKE's hand
         self.snapshot[50281] = 222 # Kids' shoes
+        self.snapshot[49864] = 239 # HAYLEY's and little girl's back foot
+        self.snapshot[50877] = 238 # HAYLEY's and little girl's foot
+        self.snapshot[47209] = 231 # Boys' hands
+        self.snapshot[53853] = 223 # ALBERT's waist
+        self.snapshot[54865] = 127 # Under Albert's arm
+        self.snapshot[52316] = 191 # Back of Albert's head (1)
+        self.snapshot[54876] = 191 # Back of Albert's head (2)
+        self.snapshot[52089] = 30  # Mr Creak's hand (1)
+        self.snapshot[52345] = 222 # Mr Creak's hand (2)
+
+        # MR ROCKITT's lab coat (arm up)
+        self.snapshot[51644] = 232
+        self.snapshot[51900] = 232
+        self.snapshot[52668] = 36
+        self.snapshot[52924] = 164
+        self.snapshot[53180] = 44
+        self.snapshot[53436] = 172
+        self.snapshot[53692] = 46
+        self.snapshot[53948] = 174
+        self.snapshot[54204] = 54
+        self.snapshot[54460] = 182
+        self.snapshot[54716] = 53
+        self.snapshot[54972] = 181
+
+    def fix_sprites(self, pixels):
+        """Apply fixes to graphic glitches that cannot be fixed by adjusting
+        tiles (because the tiles are used in multiple places, and the fix
+        applies to a subset of those places).
+        """
+        for y, x in (
+            # Eric's face
+            ( 10,   7), ( 10,  55), ( 10, 103), ( 10, 175), ( 10, 199), ( 10, 223), ( 10, 247),
+            ( 11,   7), ( 11,  55), ( 11, 103), ( 11, 175), ( 11, 199), ( 11, 223), ( 11, 247),
+            ( 12,   7), ( 12,  55), ( 12, 103), ( 12, 175), ( 12, 199), ( 12, 223), ( 12, 247),
+            ( 13,   7), ( 13,  55), ( 13, 103), ( 13, 175), ( 13, 199),             ( 13, 247),
+            ( 14,   7), ( 14,  55), ( 14, 103),             ( 14, 199),             ( 14, 247),
+
+            # BOY WANDER's face
+            ( 41,   7), ( 41,  55), ( 41, 103), ( 41, 175), ( 41, 247), ( 41, 271),
+            ( 43,   7), ( 43,  55), ( 43, 103), ( 43, 175), ( 43, 247),
+            ( 44,   7), ( 44,  55), ( 44, 103), ( 44, 175), ( 44, 247),
+            ( 45,   7), ( 45,  55), ( 45, 103), ( 45, 175), ( 45, 247),
+            ( 46,   7), ( 46,  55), ( 46, 103),             ( 46, 247),
+
+            # ANGELFACE's head
+            ( 73,   7), ( 73,  55), ( 73, 103), ( 73, 199), ( 73, 223),
+
+            (152,  27), # Little boy's hand
+            (191,  55), # MR WACKER's foot
+            (239, 233), (239, 281), # Albert's elbow
+            (253,  88), (254,  88)  # MISS TAKE's gown
+        ):
+            pixels[y][x] = 16
+
+        # End of the frog's leg
+        pixels[46][352] = 15
 
     def get_shield_udgs(self):
         return (self.get_skool_udg(2, 74), self.get_skool_udg(2, 79), self.get_skool_udg(2, 82))
@@ -698,11 +866,17 @@ class BTSMemory(SkoolMemory):
                 if data:
                     logo_udgs[y][-x].data = data
 
+    def get_message_box_udgs(self):
+        udg = Udg(16, [0] * 8)
+        return [[udg] * 8] * 3
+
 class ImageWriter:
-    def write_image(self, udgs, fname, scale, mask, width, flip):
+    def write_image(self, udgs, fname, scale, mask, width, flip, switch, post_process):
         if flip:
             udgs = self._flip_udgs(udgs)
-        self._write_image(udgs, fname, scale, mask, width)
+        if switch:
+            udgs = self._switch_udgs(udgs)
+        self._write_image(udgs, fname, scale, mask, width, post_process)
 
     def _open_file(self, fname):
         return open(fname, 'wb')
@@ -759,8 +933,10 @@ class ImageWriter:
         colours.append(image.colorAllocate(TRANSPARENT))
         return colours
 
-    def _gd_write_image(self, udgs, img_file, scale=2, mask=False, width=None):
+    def _gd_write_image(self, udgs, img_file, scale, mask, width, post_process):
         pixel_array = self._get_pixel_array(udgs, mask)
+        if post_process:
+            post_process(pixel_array)
         width = width or len(pixel_array[0])
         image = gd.image((scale * width, scale * len(pixel_array)))
         colours = self._gd_create_colours(image)
@@ -793,8 +969,10 @@ class ImageWriter:
         self.colours.extend(BRIGHT_WHITE)
         self.colours.extend(TRANSPARENT)
 
-    def _pil_write_image(self, udgs, img_file, scale=2, mask=False, width=None):
+    def _pil_write_image(self, udgs, img_file, scale, mask, width, post_process):
         pixel_array = self._get_pixel_array(udgs, mask)
+        if post_process:
+            post_process(pixel_array)
         width = width or len(pixel_array[0])
         image = Image.new('P', (scale * width, scale * len(pixel_array)), None)
         image.putpalette(self.colours)
@@ -836,3 +1014,15 @@ class ImageWriter:
             f = 2 * f + (byte & 1)
             byte /= 2
         return f
+
+    def _switch_udgs(self, udgs):
+        switched = []
+        for row in udgs:
+            switched_row = [None] * len(row)
+            for i, udg in enumerate(row):
+                if i % 2:
+                    switched_row[i - 1] = udg
+                else:
+                    switched_row[i + 1] = udg
+            switched.append(switched_row)
+        return switched
