@@ -21,8 +21,12 @@ import os
 from skoolids import *
 import animatorystates as states
 import graphics
+import skoolbuilder
 import sound
 
+CONFIG_SEPARATOR = ', '
+SEPARATOR = ', '
+
 class SkoolIniMaker:
     def __init__(self, custom):
         self.custom = custom
@@ -92,12 +96,12 @@ class SkoolIniMaker:
         self.write_command_lists()
 
         self.open_file('config.ini')
-        self.write_game_config()
-        self.write_timetable_config()
-        self.write_lesson_config()
-        self.write_timing_config()
-        self.write_screen_config()
-        self.write_images()
+        self.write_config('GameConfig', self.game_config)
+        self.write_config('TimetableConfig', self.timetable_config)
+        self.write_config('LessonConfig', self.lesson_config)
+        self.write_config('TimingConfig', self.timing_config)
+        self.write_config('ScreenConfig', self.screen_config)
+        self.write_config('Images', self.images)
         self.write_sounds()
         self.write_mouse_locations()
         self.write_random_locations()
@@ -114,7 +118,7 @@ class SkoolIniMaker:
         self.write_lessons()
 
         self.open_file('messages.ini')
-        self.write_message_config()
+        self.write_config('MessageConfig', self.message_config)
         self.write_sit_down_messages()
         self.write_assembly_messages()
         self.write_blackboard_messages()
@@ -166,9 +170,9 @@ class SkoolIniMaker:
 
     def create_game_config(self):
         self.game_config = []
-        self.game_config.append(('ImagesDir', 'images'))
         self.game_config.append(('ImageSet', 'original'))
-        self.game_config.append(('SoundsDir', 'sounds'))
+        self.game_config.append(('Icon', 'icon.png'))
+        self.game_config.append(('ScreenshotDir', '.'))
         self.game_config.append(('MaxLines', 10000))
         self.game_config.append(('TooManyLinesCommandList', CL_EXPEL_ERIC_TOO_MANY_LINES))
         self.game_config.append(('ExpellerId', WACKER))
@@ -181,16 +185,9 @@ class SkoolIniMaker:
         self.game_config.append(('LinesGivingRange', (10, 3)))
         self.game_config.append(('HitProbability', 0.5))
         self.game_config.append(('FireCatapultProbability', 0.5))
-        self.game_config.append(('WriteOnBoardProbability', 0.375))
-        self.game_config.append(('BlackboardBacktrack', 3))
-        self.game_config.append(('BlackboardPaceDistance', 3))
-        self.game_config.append(('SecretInk', (205, 198, 205)))
-        self.game_config.append(('SecretPaper', (0, 0, 0)))
         self.game_config.append(('LinesRange', (1, 8)))
-        self.game_config.append(('LinesInk', (205, 198, 205)))
-        self.game_config.append(('LinesPaperEric', (197, 0, 0)))
-        self.game_config.append(('LinesPaperOther', (0, 198, 0)))
         self.game_config.append(('SpriteSize', (3, 4)))
+        self.game_config.append(('SaveGameCompression', 9))
 
     def create_timetable_config(self):
         self.timetable_config = []
@@ -201,10 +198,9 @@ class SkoolIniMaker:
 
     def create_lesson_config(self):
         self.lesson_config = []
-        self.lesson_config.append(('GrassForHittingProbability', 0.140625))
-        self.lesson_config.append(('LinesForTalesProbability', 0.328125))
-        self.lesson_config.append(('EricsTeacherWriteOnBoardProbability', 0.28125))
-        self.lesson_config.append(('QASessionProbability', 0.90625))
+        self.lesson_config.append(('WriteOnBoardProbability', 0.375))
+        self.lesson_config.append(('BlackboardBacktrack', 3))
+        self.lesson_config.append(('BlackboardPaceDistance', 3))
 
     def create_timing_config(self):
         self.timing_config = []
@@ -231,26 +227,31 @@ class SkoolIniMaker:
         self.screen_config.append(('ScrollLeftOffset', 10))
         self.screen_config.append(('ScrollColumns', 8))
         self.screen_config.append(('SpeechBubbleSize', (8, 3)))
-        self.screen_config.append(('OpenLipByte', 66))
+        self.screen_config.append(('SpeechBubbleLipCoords', (8, 0)))
+        self.screen_config.append(('SpeechBubbleLipSize', (1, 1)))
         self.screen_config.append(('SpeechBubbleInset', (4, 4)))
         self.screen_config.append(('SpeechBubbleInk', (0, 0, 0)))
-        self.screen_config.append(('SpeechBubblePaper', (205, 198, 205)))
+        self.screen_config.append(('SpeechBubbleKey', (0, 254, 0)))
         self.screen_config.append(('SpriteKey', (0, 254, 0)))
-        self.screen_config.append(('SpriteMatrixSize', (16, 8)))
+        self.screen_config.append(('SpriteMatrixWidth', 16))
         self.screen_config.append(('SkoolInkKey', (255, 255, 255)))
-        self.screen_config.append(('LessonBoxSize', (8, 3)))
-        self.screen_config.append(('LinesBubbleSize', (8, 3)))
         self.screen_config.append(('ScoreOffset', 1))
         self.screen_config.append(('LinesOffset', 9))
         self.screen_config.append(('HiScoreOffset', 17))
         self.screen_config.append(('FontInk', (0, 1, 2)))
         self.screen_config.append(('FontPaper', (255, 254, 253)))
         self.screen_config.append(('FlashCycle', 10))
+        self.screen_config.append(('MessageBoxColour', (197, 0, 0)))
+        self.screen_config.append(('MessageBoxKey', (1, 1, 1)))
+        self.screen_config.append(('LinesInk', (205, 198, 205)))
+        self.screen_config.append(('LinesPaperEric', (197, 0, 0)))
+        self.screen_config.append(('LinesPaperOther', (0, 198, 0)))
+        self.screen_config.append(('SecretInk', (205, 198, 205)))
+        self.screen_config.append(('SecretPaper', (0, 0, 0)))
 
     def create_images(self):
         self.images = []
         common_dir = 'common'
-        self.images.append((graphics.SPEECH_BUBBLE, '%s/bubble.png' % common_dir))
         self.images.append((graphics.FONT, '%s/font.png' % common_dir))
         self.images.append((graphics.SPRITES, '%s/sprites.png' % common_dir))
 
@@ -436,11 +437,13 @@ class SkoolIniMaker:
     def create_message_config(self):
         self.message_config = []
         self.message_config.append(('Newline', '^'))
-        self.message_config.append(('LinesMessageTemplate', '$n LINES^$r'))
-        self.message_config.append(('NumberOfLinesMacro', '$n'))
-        self.message_config.append(('LinesRecipientMacro', '$r'))
-        self.message_config.append(('TitleMacro', '$TITLE'))
-        self.message_config.append(('GrasseeMacro', '$1'))
+        self.message_config.append(('TitleMacro', TITLE_MACRO))
+        self.message_config.append(('GrasseeMacro', GRASSEE_MACRO))
+        self.message_config.append(('ScoreLabel', 'Score'))
+        self.message_config.append(('LinesTotalLabel', 'Lines'))
+        self.message_config.append(('HiScoreLabel', 'Hi-Sc'))
+        self.message_config.append(('NumberOfLinesMacro', NUMBER_OF_LINES_MACRO))
+        self.message_config.append(('LinesRecipientMacro', LINES_RECIPIENT_MACRO))
 
     def create_cups(self):
         self.cups = []
@@ -453,11 +456,11 @@ class SkoolIniMaker:
 
     def create_grass_messages(self):
         self.grass_messages = []
-        self.grass_messages.append(('Writers', HERO, TEARAWAY))
-        self.grass_messages.append(('WriteTale', 'Please $TITLE I cannot tell a lie . . $1 wrote on the blackboard'))
-        self.grass_messages.append(('Hitters', HERO, BULLY))
-        self.grass_messages.append(('HitTale', 'Please $TITLE I cannot tell a lie . . $1 hit me'))
-        self.grass_messages.append(('AbsentTale', 'Please $TITLE I cannot tell a lie . . $%s is not here' % HERO))
+        self.grass_messages.append((skoolbuilder.GM_WRITERS, HERO, TEARAWAY))
+        self.grass_messages.append((skoolbuilder.GM_WRITE_TALE, 'Please %s I cannot tell a lie . . %s wrote on the blackboard' % (TITLE_MACRO, GRASSEE_MACRO)))
+        self.grass_messages.append((skoolbuilder.GM_HITTERS, HERO, BULLY))
+        self.grass_messages.append((skoolbuilder.GM_HIT_TALE, 'Please %s I cannot tell a lie . . %s hit me' % (TITLE_MACRO, GRASSEE_MACRO)))
+        self.grass_messages.append((skoolbuilder.GM_ABSENT_TALE, 'Please %s I cannot tell a lie . . $%s is not here' % (TITLE_MACRO, HERO)))
 
     def create_animation_phases(self):
         self.animation_phases = []
@@ -465,139 +468,122 @@ class SkoolIniMaker:
     def write(self, line):
         self.ofile.write('%s\n' % line)
 
+    def write_section_header(self, name):
+        self.write('[%s]' % name)
+
     def end_section(self):
         self.write('')
 
-    def write_tuples(self, tuples):
+    def write_tuples(self, tuples, separator=SEPARATOR):
         for t in tuples:
-            self.write(', '.join([str(e) for e in t]))
+            self.write(separator.join([str(e) for e in t]))
 
-    def write_game_config(self):
-        self.write('[GameConfig]')
-        self.write_tuples(self.game_config)
-        self.end_section()
-
-    def write_timetable_config(self):
-        self.write('[TimetableConfig]')
-        self.write_tuples(self.timetable_config)
-        self.end_section()
-
-    def write_lesson_config(self):
-        self.write('[LessonConfig]')
-        self.write_tuples(self.lesson_config)
-        self.end_section()
-
-    def write_timing_config(self):
-        self.write('[TimingConfig]')
-        self.write_tuples(self.timing_config)
-        self.end_section()
-
-    def write_screen_config(self):
-        self.write('[ScreenConfig]')
-        self.write_tuples(self.screen_config)
+    def write_config(self, name, config):
+        self.write_section_header(name)
+        self.write_tuples(config, CONFIG_SEPARATOR)
         self.end_section()
 
     def write_images(self):
-        self.write('[Images]')
+        self.write_section_header(skoolbuilder.IMAGES)
         self.write('; imageId, path')
         self.write_tuples(self.images)
         self.end_section()
 
     def write_sounds(self):
-        self.write('[Sounds]')
+        self.write_section_header(skoolbuilder.SOUNDS)
         self.write('; soundId, path')
         self.write_tuples(self.sounds)
         self.end_section()
 
     def write_sprite_groups(self):
         for group in self.sprite_groups:
-            self.write('[SpriteGroup %s]' % group[0])
+            self.write_section_header('%s %s' % (skoolbuilder.SPRITE_GROUP, group[0]))
             self.write_tuples(group[1:])
             self.end_section()
 
     def write_eric(self):
-        self.write('[Eric]')
+        self.write_section_header(skoolbuilder.ERIC)
         self.write('; characterId, name, spriteGroupId, animatoryState, direction, (x, y), headXY, flags[, bendOverHandXY]')
         self.write_tuples([self.eric])
         self.end_section()
 
     def write_characters(self):
-        self.write('[Characters]')
+        self.write_section_header(skoolbuilder.CHARACTERS)
         self.write('; characterId, name[/title], spriteGroupId, animatoryState, direction, (x, y), headXY, flags')
         self.write_tuples(self.characters)
         self.end_section()
 
     def write_pellets(self):
-        self.write('[CatapultPellets]')
+        self.write_section_header(skoolbuilder.CATAPULT_PELLETS)
         self.write('; characterId, pelletId, spriteGroupId, commandListId, range, hitZone, hitXY')
         self.write_tuples(self.pellets)
         self.end_section()
 
     def write_water_drop(self):
         if self.water_drop:
-            self.write('[WaterDrop]')
+            self.write_section_header(skoolbuilder.WATER_DROP)
             self.write('; objectId, spriteGroupId, commandListId, hitXY')
             self.write_tuples([self.water_drop])
             self.end_section()
 
     def write_sherry_drop(self):
         if self.sherry_drop:
-            self.write('[SherryDrop]')
+            self.write_section_header(skoolbuilder.SHERRY_DROP)
             self.write('; objectId, spriteGroupId, commandListId, hitXY')
             self.write_tuples([self.sherry_drop])
             self.end_section()
 
     def write_conker(self):
         if self.conker:
-            self.write('[Conker]')
+            self.write_section_header(skoolbuilder.CONKER)
             self.write('; objectId, spriteGroupId, commandListId, minX, maxX, minY, maxY, hitXY')
             self.write_tuples([self.conker])
             self.end_section()
 
     def write_water(self):
         if self.water:
-            self.write('[Water]')
+            self.write_section_header(skoolbuilder.WATER)
             self.write('; characterId, waterId, spriteGroupId, commandListId, animationPhases')
             self.write_tuples(self.water)
             self.end_section()
 
     def write_stinkbombs(self):
         if self.stinkbombs:
-            self.write('[Stinkbombs]')
+            self.write_section_header(skoolbuilder.STINKBOMBS)
             self.write('; characterId, stinkbombId, spriteGroupId, commandListId, animationPhases, stinkRange')
             self.write_tuples(self.stinkbombs)
             self.end_section()
 
     def write_mice(self):
         if self.mice:
-            self.write('[Mice]')
+            self.write_section_header(skoolbuilder.MICE)
             self.write('; mouseId, spriteGroupId, animatoryState, (x, y), commandListId, spriteXY')
             self.write_tuples(self.mice)
             self.end_section()
 
     def write_mouse_locations(self):
         if self.mouse_locations:
-            self.write('[MouseLocations]')
+            self.write_section_header(skoolbuilder.MOUSE_LOCATIONS)
             self.write('; x, y')
             self.write_tuples(self.mouse_locations)
             self.end_section()
 
     def write_frogs(self):
         if self.frogs:
-            self.write('[Frogs]')
+            self.write_section_header(skoolbuilder.FROGS)
             self.write('; frogId, spriteGroupId, animatoryState, (x, y), commandListId, turnRound, shortHop, longHop, sitXY, ericProximity')
             self.write_tuples(self.frogs)
             self.end_section()
 
     def write_bike(self):
         if self.bike:
-            self.write('[Bike]')
+            self.write_section_header(skoolbuilder.BIKE)
             self.write('; bikeId, spriteGroupId, animatoryState, unchainXY, commandListId, topLeft, size, coords, moveDelay, pedalMomentum, maxMomentum')
             self.write_tuples([self.bike])
             self.end_section()
 
     def write_timetable(self):
-        self.write('[Timetable]')
+        self.write_section_header(skoolbuilder.TIMETABLE)
         self.write('; lessonID')
         for lesson_id in self.timetable:
             self.write(lesson_id)
@@ -605,7 +591,7 @@ class SkoolIniMaker:
 
     def write_special_playtimes(self):
         if self.special_playtimes:
-            self.write('[SpecialPlaytimes]')
+            self.write_section_header(skoolbuilder.SPECIAL_PLAYTIMES)
             self.write('; lessonID')
             for lesson_id in self.special_playtimes:
                 self.write(lesson_id)
@@ -613,13 +599,13 @@ class SkoolIniMaker:
 
     def write_lessons(self):
         for lesson in self.lessons:
-            self.write('[Lesson %s %s]' % (lesson.lesson_id, ', '.join(lesson.details)))
+            self.write_section_header('%s %s %s' % (skoolbuilder.LESSON, lesson.lesson_id, ', '.join(lesson.details)))
             self.write('; characterId, commandListID')
             self.write_tuples(lesson.entries)
             self.end_section()
 
     def write_random_locations(self):
-        self.write('[RandomLocations]')
+        self.write_section_header(skoolbuilder.RANDOM_LOCATIONS)
         self.write('; characterID, (x, y), (x, y)...')
         for c in self.characters:
             character_id = c[0]
@@ -627,7 +613,7 @@ class SkoolIniMaker:
         self.end_section()
 
     def write_skool_locations(self):
-        self.write('[SkoolLocations]')
+        self.write_section_header(skoolbuilder.SKOOL_LOCATIONS)
         self.write('; locationId, x, y')
         self.skool_locations.sort(key=lambda loc: loc[2])
         for x, y, location_id in self.skool_locations:
@@ -636,78 +622,78 @@ class SkoolIniMaker:
 
     def write_inventory(self):
         if self.inventory:
-            self.write('[Inventory]')
+            self.write_section_header(skoolbuilder.INVENTORY)
             self.write('; itemId, topLeft, size')
             self.write_tuples(self.inventory)
             self.end_section()
 
     def write_command_lists(self):
         for tap in self.taps:
-            self.write('[CommandList %s]' % tap.name)
+            self.write_section_header('%s %s' % (skoolbuilder.COMMAND_LIST, tap.name))
             for elements in tap.commands:
                 self.write_tuples([elements])
             self.end_section()
 
     def write_rooms(self):
-        self.write('[Rooms]')
+        self.write_section_header(skoolbuilder.ROOMS)
         self.write('; roomId, name, topLeft, bottomRight, getAlong')
         self.write_tuples(self.rooms)
         self.end_section()
 
     def write_chairs(self):
-        self.write('[Chairs]')
+        self.write_section_header(skoolbuilder.CHAIRS)
         self.write('; roomId, x1, x2,...')
         self.write_tuples(self.chairs)
         self.end_section()
 
     def write_desks(self):
         if self.desks:
-            self.write('[Desks]')
+            self.write_section_header(skoolbuilder.DESKS)
             self.write('; roomId, x1, x2,...')
             self.write_tuples(self.desks)
             self.end_section()
 
     def write_desk_lid(self):
         if self.desk_lid:
-            self.write('[DeskLid]')
+            self.write_section_header(skoolbuilder.DESK_LID)
             self.write('; deskLidId, spriteGroupId, commandListId, xOffset')
             self.write_tuples([self.desk_lid])
             self.end_section()
 
     def write_doors(self):
         if self.doors:
-            self.write('[Doors]')
+            self.write_section_header(skoolbuilder.DOORS)
             self.write('; doorId, x, bottomY, topY, initiallyShut, autoShutDelay, shutTopLeft, size, coords[, climb[, fly]]')
             self.write_tuples(self.doors)
             self.end_section()
 
     def write_windows(self):
         if self.windows:
-            self.write('[Windows]')
+            self.write_section_header(skoolbuilder.WINDOWS)
             self.write('; windowId, x, bottomY, topY, initiallyShut, openerCoords, shutTopLeft, size, coords, descentPhases[, notABird]')
             self.write_tuples(self.windows)
             self.end_section()
 
     def write_walls(self):
-        self.write('[Walls]')
+        self.write_section_header(skoolbuilder.WALLS)
         self.write('; wallId, x, bottomY, topY')
         self.write_tuples(self.walls)
         self.end_section()
 
     def write_staircases(self):
-        self.write('[Staircases]')
+        self.write_section_header(skoolbuilder.STAIRCASES)
         self.write('; staircaseId[:alias], bottom, top[, force]')
         self.write_tuples(self.staircases)
         self.end_section()
 
     def write_floors(self):
-        self.write('[Floors]')
+        self.write_section_header(skoolbuilder.FLOORS)
         self.write('; floorId, minX, maxX, y')
         self.write_tuples(self.floors)
         self.end_section()
 
     def write_routes(self):
-        self.write('[Routes]')
+        self.write_section_header(skoolbuilder.ROUTES)
         self.write('; homeFloorId, destFloorId|*[, destFloorId[, ...]], nextStaircaseId')
         for home_floor_id in self.routes:
             for route in self.routes[home_floor_id]:
@@ -717,24 +703,19 @@ class SkoolIniMaker:
         self.end_section()
 
     def write_no_go_zones(self):
-        self.write('[NoGoZones]')
+        self.write_section_header(skoolbuilder.NO_GO_ZONES)
         self.write('; zoneId, minX, maxX, bottomY, topY')
         self.write_tuples(self.no_go_zones)
         self.end_section()
 
-    def write_message_config(self):
-        self.write('[MessageConfig]')
-        self.write_tuples(self.message_config)
-        self.end_section()
-
     def write_sit_down_messages(self):
-        self.write('[SitDownMessages]')
+        self.write_section_header(skoolbuilder.SIT_DOWN_MESSAGES)
         self.write('; characterId, sitDownMessage')
         self.write_tuples(self.sit_down_messages)
         self.end_section()
 
     def write_font(self):
-        self.write('[Font]')
+        self.write_section_header(skoolbuilder.FONT)
         self.write('; char, offset, width')
         offset = 0
         for char, width in self.font:
@@ -746,19 +727,19 @@ class SkoolIniMaker:
     def write_assembly_messages(self):
         if not self.assembly_messages:
             return
-        self.write('[AssemblyMessages]')
+        self.write_section_header(skoolbuilder.ASSEMBLY_MESSAGES)
         self.write_tuples(self.assembly_messages)
         self.end_section()
 
     def write_blackboards(self):
-        self.write('[Blackboards]')
+        self.write_section_header(skoolbuilder.BLACKBOARDS)
         self.write('; roomId, topLeft, size, chalk')
         self.write_tuples(self.blackboards)
         self.end_section()
 
     def write_blackboard_messages(self):
         for character_id in self.blackboard_messages:
-            self.write('[BlackboardMessages %s]' % character_id)
+            self.write_section_header('%s %s' % (skoolbuilder.BLACKBOARD_MESSAGES, character_id))
             for message in self.blackboard_messages[character_id]:
                 self.write(message)
             self.end_section()
@@ -766,66 +747,66 @@ class SkoolIniMaker:
     def write_questions_and_answers(self):
         for teacher_id in self.questions_and_answers:
             specials, questions, answers, qa_pairs = self.questions_and_answers[teacher_id]
-            self.write('[QuestionsAndAnswers %s]' % teacher_id)
+            self.write_section_header('%s %s' % (skoolbuilder.QUESTIONS_AND_ANSWERS, teacher_id))
             if specials:
-                self.write('SpecialGroup, %s, %i' % (specials[0][0], specials[0][1]))
-                self.write('SpecialQuestion, %s' % specials[1])
-                self.write('SpecialAnswer, %s' % specials[2])
+                self.write('%s, %s, %i' % (skoolbuilder.QA_SPECIAL_GROUP, specials[0][0], specials[0][1]))
+                self.write('%s, %s' % (skoolbuilder.QA_SPECIAL_QUESTION, specials[1]))
+                self.write('%s, %s' % (skoolbuilder.QA_SPECIAL_ANSWER, specials[2]))
             self.write('; Question, questionId, groupId, questionTemplate')
-            self.write_tuples([['Question'] + list(q) for q in questions])
+            self.write_tuples([[skoolbuilder.QA_QUESTION] + list(q) for q in questions])
             self.write('; Answer, questionId, answerTemplate')
-            self.write_tuples([['Answer'] + list(a) for a in answers])
+            self.write_tuples([[skoolbuilder.QA_ANSWER] + list(a) for a in answers])
             self.write('; groupId, word1, word2')
             self.write_tuples(qa_pairs)
             self.end_section()
 
     def write_lines_messages(self):
-        self.write('[LinesMessages]')
+        self.write_section_header(skoolbuilder.LINES_MESSAGES)
         self.write('; characterId|*, linesMessageId, linesMessage')
         self.write_tuples(self.lines_messages)
         self.end_section()
 
     def write_lesson_messages(self):
-        self.write('[LessonMessages]')
+        self.write_section_header(skoolbuilder.LESSON_MESSAGES)
         self.write('; characterId|*, lessonMessage[, condition]')
         self.write_tuples(self.lesson_messages)
         self.end_section()
 
     def write_shields(self):
         if self.shields:
-            self.write('[Shields]')
+            self.write_section_header(skoolbuilder.SHIELDS)
             self.write('; score, topLeft, size, coords')
             self.write_tuples(self.shields)
             self.end_section()
 
     def write_safe(self):
-        self.write('[Safe]')
+        self.write_section_header(skoolbuilder.SAFE)
         self.write('; topLeft, size, coords')
         self.write_tuples([self.safe])
         self.end_section()
 
     def write_cups(self):
         if self.cups:
-            self.write('[Cups]')
+            self.write_section_header(skoolbuilder.CUPS)
             self.write('; cupId, emptyTopLeft, size, coords')
             self.write_tuples(self.cups)
             self.end_section()
 
     def write_plants(self):
         if self.plants:
-            self.write('[Plants]')
+            self.write_section_header(skoolbuilder.PLANTS)
             self.write('; plantId, spriteGroupId, x, y, commandListId')
             self.write_tuples(self.plants)
             self.end_section()
 
     def write_grass_messages(self):
-        self.write('[GrassMessages]')
+        self.write_section_header(skoolbuilder.GRASS_MESSAGES)
         self.write_tuples(self.grass_messages)
         self.end_section()
 
     def write_animation_phases(self):
         for phase_set in self.animation_phases:
-            self.write('[AnimationPhases %s]' % phase_set[0])
+            self.write_section_header('%s %s' % (skoolbuilder.ANIMATION_PHASES, phase_set[0]))
             self.write('; %s' % phase_set[1])
             self.write_tuples(phase_set[2:])
             self.end_section()
